@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -13,6 +13,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+import warnings
+
 from tencentcloud.common.abstract_model import AbstractModel
 
 
@@ -35,6 +37,13 @@ class CosBackup(AbstractModel):
     def _deserialize(self, params):
         self.IsAutoBackup = params.get("IsAutoBackup")
         self.BackupTime = params.get("BackupTime")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class CreateInstanceRequest(AbstractModel):
@@ -46,7 +55,7 @@ class CreateInstanceRequest(AbstractModel):
         """
         :param Zone: 可用区
         :type Zone: str
-        :param EsVersion: 实例版本（支持"5.6.4"、"6.4.3"、"6.8.2"、"7.5.1"）
+        :param EsVersion: 实例版本（支持"5.6.4"、"6.4.3"、"6.8.2"、"7.5.1"、"7.10.1"）
         :type EsVersion: str
         :param VpcId: 私有网络ID
         :type VpcId: str
@@ -108,6 +117,8 @@ class CreateInstanceRequest(AbstractModel):
         :type BasicSecurityType: int
         :param SceneType: 场景化模板类型 0：不启用 1：通用 2：日志 3：搜索
         :type SceneType: int
+        :param WebNodeTypeInfo: 可视化节点配置
+        :type WebNodeTypeInfo: :class:`tencentcloud.es.v20180416.models.WebNodeTypeInfo`
         """
         self.Zone = None
         self.EsVersion = None
@@ -137,6 +148,7 @@ class CreateInstanceRequest(AbstractModel):
         self.TagList = None
         self.BasicSecurityType = None
         self.SceneType = None
+        self.WebNodeTypeInfo = None
 
 
     def _deserialize(self, params):
@@ -183,6 +195,16 @@ class CreateInstanceRequest(AbstractModel):
                 self.TagList.append(obj)
         self.BasicSecurityType = params.get("BasicSecurityType")
         self.SceneType = params.get("SceneType")
+        if params.get("WebNodeTypeInfo") is not None:
+            self.WebNodeTypeInfo = WebNodeTypeInfo()
+            self.WebNodeTypeInfo._deserialize(params.get("WebNodeTypeInfo"))
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class CreateInstanceResponse(AbstractModel):
@@ -221,6 +243,13 @@ class DeleteInstanceRequest(AbstractModel):
 
     def _deserialize(self, params):
         self.InstanceId = params.get("InstanceId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DeleteInstanceResponse(AbstractModel):
@@ -289,6 +318,13 @@ class DescribeInstanceLogsRequest(AbstractModel):
         self.Offset = params.get("Offset")
         self.Limit = params.get("Limit")
         self.OrderByType = params.get("OrderByType")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DescribeInstanceLogsResponse(AbstractModel):
@@ -352,6 +388,13 @@ class DescribeInstanceOperationsRequest(AbstractModel):
         self.EndTime = params.get("EndTime")
         self.Offset = params.get("Offset")
         self.Limit = params.get("Limit")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DescribeInstanceOperationsResponse(AbstractModel):
@@ -436,6 +479,13 @@ class DescribeInstancesRequest(AbstractModel):
                 obj._deserialize(item)
                 self.TagList.append(obj)
         self.IpList = params.get("IpList")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DescribeInstancesResponse(AbstractModel):
@@ -468,6 +518,55 @@ class DescribeInstancesResponse(AbstractModel):
         self.RequestId = params.get("RequestId")
 
 
+class DiagnoseInstanceRequest(AbstractModel):
+    """DiagnoseInstance请求参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param InstanceId: ES实例ID
+        :type InstanceId: str
+        :param DiagnoseJobs: 需要触发的诊断项
+        :type DiagnoseJobs: list of str
+        :param DiagnoseIndices: 需要诊断的索引，支持通配符
+        :type DiagnoseIndices: str
+        """
+        self.InstanceId = None
+        self.DiagnoseJobs = None
+        self.DiagnoseIndices = None
+
+
+    def _deserialize(self, params):
+        self.InstanceId = params.get("InstanceId")
+        self.DiagnoseJobs = params.get("DiagnoseJobs")
+        self.DiagnoseIndices = params.get("DiagnoseIndices")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class DiagnoseInstanceResponse(AbstractModel):
+    """DiagnoseInstance返回参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        self.RequestId = params.get("RequestId")
+
+
 class DictInfo(AbstractModel):
     """ik插件词典信息
 
@@ -491,6 +590,13 @@ class DictInfo(AbstractModel):
         self.Key = params.get("Key")
         self.Name = params.get("Name")
         self.Size = params.get("Size")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class EsAcl(AbstractModel):
@@ -512,6 +618,13 @@ class EsAcl(AbstractModel):
     def _deserialize(self, params):
         self.BlackIpList = params.get("BlackIpList")
         self.WhiteIpList = params.get("WhiteIpList")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class EsDictionaryInfo(AbstractModel):
@@ -565,6 +678,13 @@ class EsDictionaryInfo(AbstractModel):
                 obj._deserialize(item)
                 self.Synonym.append(obj)
         self.UpdateType = params.get("UpdateType")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class EsPublicAcl(AbstractModel):
@@ -586,6 +706,13 @@ class EsPublicAcl(AbstractModel):
     def _deserialize(self, params):
         self.BlackIpList = params.get("BlackIpList")
         self.WhiteIpList = params.get("WhiteIpList")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class GetRequestTargetNodeTypesRequest(AbstractModel):
@@ -603,6 +730,13 @@ class GetRequestTargetNodeTypesRequest(AbstractModel):
 
     def _deserialize(self, params):
         self.InstanceId = params.get("InstanceId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class GetRequestTargetNodeTypesResponse(AbstractModel):
@@ -759,6 +893,9 @@ class InstanceInfo(AbstractModel):
         :param KibanaConfig: Kibana配置项
 注意：此字段可能返回 null，表示取不到有效值。
         :type KibanaConfig: str
+        :param KibanaNodeInfo: Kibana节点信息
+注意：此字段可能返回 null，表示取不到有效值。
+        :type KibanaNodeInfo: :class:`tencentcloud.es.v20180416.models.KibanaNodeInfo`
         """
         self.InstanceId = None
         self.InstanceName = None
@@ -814,6 +951,7 @@ class InstanceInfo(AbstractModel):
         self.SecurityType = None
         self.SceneType = None
         self.KibanaConfig = None
+        self.KibanaNodeInfo = None
 
 
     def _deserialize(self, params):
@@ -896,6 +1034,16 @@ class InstanceInfo(AbstractModel):
         self.SecurityType = params.get("SecurityType")
         self.SceneType = params.get("SceneType")
         self.KibanaConfig = params.get("KibanaConfig")
+        if params.get("KibanaNodeInfo") is not None:
+            self.KibanaNodeInfo = KibanaNodeInfo()
+            self.KibanaNodeInfo._deserialize(params.get("KibanaNodeInfo"))
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class InstanceLog(AbstractModel):
@@ -925,6 +1073,13 @@ class InstanceLog(AbstractModel):
         self.Level = params.get("Level")
         self.Ip = params.get("Ip")
         self.Message = params.get("Message")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class KeyValue(AbstractModel):
@@ -946,6 +1101,57 @@ class KeyValue(AbstractModel):
     def _deserialize(self, params):
         self.Key = params.get("Key")
         self.Value = params.get("Value")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class KibanaNodeInfo(AbstractModel):
+    """实例Kibana节点相关信息
+
+    """
+
+    def __init__(self):
+        """
+        :param KibanaNodeType: Kibana节点规格
+        :type KibanaNodeType: str
+        :param KibanaNodeNum: Kibana节点个数
+        :type KibanaNodeNum: int
+        :param KibanaNodeCpuNum: Kibana节点CPU数
+        :type KibanaNodeCpuNum: int
+        :param KibanaNodeMemSize: Kibana节点内存GB
+        :type KibanaNodeMemSize: int
+        :param KibanaNodeDiskType: Kibana节点磁盘类型
+        :type KibanaNodeDiskType: str
+        :param KibanaNodeDiskSize: Kibana节点磁盘大小
+        :type KibanaNodeDiskSize: int
+        """
+        self.KibanaNodeType = None
+        self.KibanaNodeNum = None
+        self.KibanaNodeCpuNum = None
+        self.KibanaNodeMemSize = None
+        self.KibanaNodeDiskType = None
+        self.KibanaNodeDiskSize = None
+
+
+    def _deserialize(self, params):
+        self.KibanaNodeType = params.get("KibanaNodeType")
+        self.KibanaNodeNum = params.get("KibanaNodeNum")
+        self.KibanaNodeCpuNum = params.get("KibanaNodeCpuNum")
+        self.KibanaNodeMemSize = params.get("KibanaNodeMemSize")
+        self.KibanaNodeDiskType = params.get("KibanaNodeDiskType")
+        self.KibanaNodeDiskSize = params.get("KibanaNodeDiskSize")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class LocalDiskInfo(AbstractModel):
@@ -971,6 +1177,13 @@ class LocalDiskInfo(AbstractModel):
         self.LocalDiskType = params.get("LocalDiskType")
         self.LocalDiskSize = params.get("LocalDiskSize")
         self.LocalDiskCount = params.get("LocalDiskCount")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class MasterNodeInfo(AbstractModel):
@@ -1012,6 +1225,13 @@ class MasterNodeInfo(AbstractModel):
         self.MasterNodeMemSize = params.get("MasterNodeMemSize")
         self.MasterNodeDiskSize = params.get("MasterNodeDiskSize")
         self.MasterNodeDiskType = params.get("MasterNodeDiskType")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class NodeInfo(AbstractModel):
@@ -1028,6 +1248,7 @@ class NodeInfo(AbstractModel):
         :param Type: 节点类型<li>hotData: 热数据节点</li>
 <li>warmData: 冷数据节点</li>
 <li>dedicatedMaster: 专用主节点</li>
+<li>kibana: Kibana节点</li>
 默认值为hotData
         :type Type: str
         :param DiskType: 节点磁盘类型<li>CLOUD_SSD：SSD云硬盘</li><li>CLOUD_PREMIUM：高硬能云硬盘</li>默认值CLOUD_SSD
@@ -1063,6 +1284,13 @@ class NodeInfo(AbstractModel):
             self.LocalDiskInfo._deserialize(params.get("LocalDiskInfo"))
         self.DiskCount = params.get("DiskCount")
         self.DiskEncrypt = params.get("DiskEncrypt")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class Operation(AbstractModel):
@@ -1111,6 +1339,13 @@ class Operation(AbstractModel):
                 obj._deserialize(item)
                 self.Tasks.append(obj)
         self.Progress = params.get("Progress")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class OperationDetail(AbstractModel):
@@ -1142,6 +1377,13 @@ class OperationDetail(AbstractModel):
                 obj = KeyValue()
                 obj._deserialize(item)
                 self.NewInfo.append(obj)
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class RestartInstanceRequest(AbstractModel):
@@ -1163,6 +1405,13 @@ class RestartInstanceRequest(AbstractModel):
     def _deserialize(self, params):
         self.InstanceId = params.get("InstanceId")
         self.ForceRestart = params.get("ForceRestart")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class RestartInstanceResponse(AbstractModel):
@@ -1197,6 +1446,13 @@ class RestartKibanaRequest(AbstractModel):
 
     def _deserialize(self, params):
         self.InstanceId = params.get("InstanceId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class RestartKibanaResponse(AbstractModel):
@@ -1239,6 +1495,13 @@ class RestartNodesRequest(AbstractModel):
         self.InstanceId = params.get("InstanceId")
         self.NodeNames = params.get("NodeNames")
         self.ForceRestart = params.get("ForceRestart")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class RestartNodesResponse(AbstractModel):
@@ -1301,6 +1564,13 @@ class SubTaskDetail(AbstractModel):
         self.FailedIndices = params.get("FailedIndices")
         self.FinishTime = params.get("FinishTime")
         self.Level = params.get("Level")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class TagInfo(AbstractModel):
@@ -1322,6 +1592,13 @@ class TagInfo(AbstractModel):
     def _deserialize(self, params):
         self.TagKey = params.get("TagKey")
         self.TagValue = params.get("TagValue")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class TaskDetail(AbstractModel):
@@ -1356,6 +1633,62 @@ class TaskDetail(AbstractModel):
                 obj = SubTaskDetail()
                 obj._deserialize(item)
                 self.SubTasks.append(obj)
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class UpdateDiagnoseSettingsRequest(AbstractModel):
+    """UpdateDiagnoseSettings请求参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param InstanceId: ES实例ID
+        :type InstanceId: str
+        :param Status: 0：开启智能运维；-1：关闭智能运维
+        :type Status: int
+        :param CronTime: 智能运维每天定时巡检时间
+        :type CronTime: str
+        """
+        self.InstanceId = None
+        self.Status = None
+        self.CronTime = None
+
+
+    def _deserialize(self, params):
+        self.InstanceId = params.get("InstanceId")
+        self.Status = params.get("Status")
+        self.CronTime = params.get("CronTime")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class UpdateDiagnoseSettingsResponse(AbstractModel):
+    """UpdateDiagnoseSettings返回参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        self.RequestId = params.get("RequestId")
 
 
 class UpdateInstanceRequest(AbstractModel):
@@ -1487,6 +1820,13 @@ class UpdateInstanceRequest(AbstractModel):
                 self.MultiZoneInfo.append(obj)
         self.SceneType = params.get("SceneType")
         self.KibanaConfig = params.get("KibanaConfig")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class UpdateInstanceResponse(AbstractModel):
@@ -1521,11 +1861,14 @@ class UpdatePluginsRequest(AbstractModel):
         :type RemovePluginList: list of str
         :param ForceRestart: 是否强制重启
         :type ForceRestart: bool
+        :param ForceUpdate: 是否重新安装
+        :type ForceUpdate: bool
         """
         self.InstanceId = None
         self.InstallPluginList = None
         self.RemovePluginList = None
         self.ForceRestart = None
+        self.ForceUpdate = None
 
 
     def _deserialize(self, params):
@@ -1533,6 +1876,14 @@ class UpdatePluginsRequest(AbstractModel):
         self.InstallPluginList = params.get("InstallPluginList")
         self.RemovePluginList = params.get("RemovePluginList")
         self.ForceRestart = params.get("ForceRestart")
+        self.ForceUpdate = params.get("ForceUpdate")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class UpdatePluginsResponse(AbstractModel):
@@ -1571,6 +1922,13 @@ class UpdateRequestTargetNodeTypesRequest(AbstractModel):
     def _deserialize(self, params):
         self.InstanceId = params.get("InstanceId")
         self.TargetNodeTypes = params.get("TargetNodeTypes")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class UpdateRequestTargetNodeTypesResponse(AbstractModel):
@@ -1625,6 +1983,13 @@ class UpgradeInstanceRequest(AbstractModel):
         self.LicenseType = params.get("LicenseType")
         self.BasicSecurityType = params.get("BasicSecurityType")
         self.UpgradeMode = params.get("UpgradeMode")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class UpgradeInstanceResponse(AbstractModel):
@@ -1679,6 +2044,13 @@ class UpgradeLicenseRequest(AbstractModel):
         self.VoucherIds = params.get("VoucherIds")
         self.BasicSecurityType = params.get("BasicSecurityType")
         self.ForceRestart = params.get("ForceRestart")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class UpgradeLicenseResponse(AbstractModel):
@@ -1698,6 +2070,34 @@ class UpgradeLicenseResponse(AbstractModel):
         self.RequestId = params.get("RequestId")
 
 
+class WebNodeTypeInfo(AbstractModel):
+    """可视化节点配置
+
+    """
+
+    def __init__(self):
+        """
+        :param NodeNum: 可视化节点个数，固定为1
+        :type NodeNum: int
+        :param NodeType: 可视化节点规格
+        :type NodeType: str
+        """
+        self.NodeNum = None
+        self.NodeType = None
+
+
+    def _deserialize(self, params):
+        self.NodeNum = params.get("NodeNum")
+        self.NodeType = params.get("NodeType")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
 class ZoneDetail(AbstractModel):
     """多可用区部署时可用区的详细信息
 
@@ -1716,4 +2116,11 @@ class ZoneDetail(AbstractModel):
 
     def _deserialize(self, params):
         self.Zone = params.get("Zone")
-        self.SubnetId = params.get("SubnetId")
\ No newline at end of file
+        self.SubnetId = params.get("SubnetId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
\ No newline at end of file
